"use strict";
/**
 * Copyright (c) 2018-present, tarant
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const mailbox_1 = tslib_1.__importDefault(require("../../mailbox/mailbox"));
const noop_supervisor_1 = tslib_1.__importDefault(require("../supervision/noop-supervisor"));
class ActorSystemConfigurationBuilder {
    constructor() {
        this.materializers = [];
        this.resolvers = [];
        this.resources = ['default'];
        this.tickInterval = 1;
        this.mailbox = mailbox_1.default.empty();
        this.supervisor = new noop_supervisor_1.default();
    }
    static define() {
        return new ActorSystemConfigurationBuilder();
    }
    withMaterializers(materializers) {
        this.materializers = materializers;
        return this;
    }
    withResolvers(resolvers) {
        this.resolvers = resolvers;
        return this;
    }
    withResources(resources) {
        this.resources = resources;
        return this;
    }
    withTickInterval(tickInterval) {
        this.tickInterval = tickInterval;
        return this;
    }
    withMailbox(mailbox) {
        this.mailbox = mailbox;
        return this;
    }
    withTopSupervisor(supervisor) {
        this.supervisor = supervisor;
        return this;
    }
    done() {
        return this;
    }
}
exports.default = ActorSystemConfigurationBuilder;
