"use strict";
/**
 * Copyright (c) 2018-present, tarant
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
Object.defineProperty(exports, "__esModule", { value: true });
class Fiber {
    static with(config) {
        return new Fiber(config);
    }
    constructor(configuration) {
        this.processors = [];
        const { resources, tickInterval } = configuration;
        this.configuration = configuration;
        this.name = `fiber-with${resources.reduce((aggregation, current) => `${aggregation}-${current}`, '')}`;
        this.timerId = setInterval(this.tick.bind(this), tickInterval);
    }
    free() {
        clearInterval(this.timerId);
    }
    acquire(processor) {
        if (processor.requirements.every((req) => this.configuration.resources.indexOf(req) !== -1)) {
            this.processors.push(processor);
            return true;
        }
        return false;
    }
    tick() {
        this.processors.forEach((p) => p.process());
    }
}
exports.default = Fiber;
