"use strict";
/**
 * Copyright (c) 2018-present, tarant
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const uuid_1 = tslib_1.__importDefault(require("../helper/uuid"));
const subscription_1 = tslib_1.__importDefault(require("./subscription"));
class Mailbox {
    constructor() {
        this.subscribedPartitions = {};
        this.subscriptions = {};
    }
    static empty() {
        return new Mailbox();
    }
    addSubscriber(subscriber) {
        const id = (0, uuid_1.default)();
        const { partitions } = subscriber;
        this.subscribedPartitions[id] = partitions;
        partitions.forEach((partition) => {
            this.subscriptions[partition] = this.subscriptions[partition] || [];
            this.subscriptions[partition].push(new subscription_1.default(id, subscriber));
        });
        return id;
    }
    removeSubscription(subscription) {
        const partitions = this.subscribedPartitions[subscription];
        partitions.forEach((partition) => (this.subscriptions[partition] = this.subscriptions[partition].filter((s) => s.id !== subscription)));
        delete this.subscribedPartitions[subscription];
    }
    push(message) {
        this.subscriptions[message.partition].forEach((subscription) => subscription.messages.push(message));
    }
    poll(subscription) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const partitions = this.subscribedPartitions[subscription];
            if (!partitions) {
                return;
            }
            partitions.forEach((partition) => this.subscriptions[partition]
                .filter((managedSubscription) => managedSubscription.id === subscription)
                .forEach((managedSubscription) => tslib_1.__awaiter(this, void 0, void 0, function* () { return yield managedSubscription.process(); })));
        });
    }
}
exports.default = Mailbox;
