"use strict";
/**
 * Copyright (c) 2018-present, tarant
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const actor_1 = tslib_1.__importDefault(require("../actor-system/actor"));
const uuid_1 = tslib_1.__importDefault(require("../helper/uuid"));
class Topic extends actor_1.default {
    /**
     * Creates a topic for the given actor system. The id of the topic will be `topics/NAME_OF_THE_TOPIC`
     *
     * @param system Actor system where the topic will live
     * @param name Name of the topic to be created
     * @param consumerClass Protocol of the topic
     */
    static for(system, name, consumerClass) {
        return system.actorOf(Topic, [name, consumerClass]);
    }
    constructor(topicName, consumerClass) {
        super('topics/' + topicName);
        this.subscriptions = new Map();
        const props = Object.getOwnPropertyNames(consumerClass.prototype);
        props
            .filter((k) => k !== 'constructor')
            .forEach((k) => {
            this.constructor.prototype[k] = (...args) => {
                // tslint:disable-next-line
                this.subscriptions.forEach((actor) => actor[k].apply(actor, args)); // eslint-disable-line
            };
        });
    }
    subscribe(t) {
        const id = (0, uuid_1.default)();
        this.subscriptions.set(id, t);
        return id;
    }
    unsubscribe(id) {
        this.subscriptions.delete(id);
    }
}
exports.default = Topic;
